
# developmental stages
boxpotOnDevelopmentalStages <- function(data=data,alpha=0.5){

  if(!desc.globals$read){
    stop("No description file was read. Please read a description file using readDescriptionFile(filename=\"data_description_file.csv\")")
  }

  oo <- order(desc.globals$plot_order)
  cols <- desc.globals$plot_colors[oo];
  for(j in 1:length(desc.globals$plot_colors)){
    tmp <- col2rgb(cols[j])/255
    cols[j] <- rgb(tmp[1],tmp[2],tmp[3],alpha=alpha)
  }
  names(cols) <- pkg.globals$dirs[oo]
  xlab <- desc.globals$plot_labels[oo]
  names(xlab) <- pkg.globals$dirs[oo]

  dirs <- pkg.globals$dirs[oo]

  if(sum(grepl("raw",names(data))) == 0){
    stop("No raw data available. You need to run \"readFeatureData()\".")
  }else{
    species <- data$raw_species;
    rois <- data$raw_rois;
    pc.mat <- data$raw_pc.mat;
  }

  feat <- feature.globals$feat;


  th.tmp <- unlist(getSizeThresholds())
  small <- th.tmp["small"]
  medium <- th.tmp["medium"]

  small.idx <- pc.mat[,1] <= small
  medium.idx <- pc.mat[,1] > small & pc.mat[,1] <= medium
  large.idx <- pc.mat[,1] > medium
  main.sz <- c("small","medium","large")
  idx.sz <- list(small.idx,medium.idx,large.idx)
  size <- rep(NA,length(species))
  size[idx.sz[[1]]] <- "s"
  size[idx.sz[[2]]] <- "m"
  size[idx.sz[[3]]] <- "l"
  leg.list <- vector("list",3)
  names(leg.list) <- dirs
  tmp.counts <- lapply(split(size,factor(species,levels = dirs)),table)
  # print(tmp.counts)
  for(nl in names(leg.list)){
    tc <- tmp.counts[[nl]]
    tv <- vector(length=4)
    if("s" %in% names(tc)){
      cs <- tc["s"]
    }else{
      cs <- 0
    }
    tv[1] <- paste0("small\n ",cs);

    if("m" %in% names(tc)){
      cs <- tc["m"]
    }else{
      cs <- 0
    }
    tv[2] <- paste0("medium\n ",cs);

    if("l" %in% names(tc)){
      cs <- tc["s"]
    }else{
      cs <- 0
    }
    tv[3] <- paste0("large\n ",cs);

    tv[4] <- paste0("all\n ",sum(tc))

    leg.list[[nl]] <- tv;
  }
  #leg.list[[1]] <- c("small\n 77","medium\n 26","large\n 0","all\n 103")
  #leg.list[[2]] <- c("small\n 21","medium\n 31","large\n 3","all\n 55")
  #leg.list[[3]] <- c("small\n 27","medium\n 21","large\n 21","all\n 69")
  leg <- unlist(leg.list)
  #print(leg)
  for(fg in names(feat)){#/area2cex
    #,height=3
    pdf(file=paste(pkg.globals$folder.results,pkg.globals$fsep,"box_plots/fg_",fg,"_boxplot_grouped_by_age_colored_by_size_small_medium_larger_ts",small,"_tm",medium,"_mod_names_one_panel_reduced_height.pdf",sep=""),width=8,height=2.5,family="Arial",useDingbats=FALSE)
    # par(mai=c(1,0.5,0.5,0.1))
    par(mai=c(0.6,0.8,0.5,0.1),mgp=c(2.2,1,0))
    fm <- feat[[fg]]
    for(k in 1:nrow(fm)){
      #ylim <- c(floor(min(pc.mat[,fm[k,"order_column"]],na.rm=TRUE)),ceiling(max(pc.mat[,fm[k,"order_column"]],na.rm=TRUE))+(0.1*ceiling(max(pc.mat[,fm[k,"order_column"]],na.rm=TRUE))))
      ylim <- c(min(pc.mat[,fm[k,"order_column"]],na.rm=TRUE),ceiling(max(pc.mat[,fm[k,"order_column"]],na.rm=TRUE)))
      tmp.list <- vector("list",length=length(dirs)*4+(length(dirs)-1))
      names_tmp.list <- c(paste(dirs[1],c("s","m","l","all"),sep="_"))
      for(j in 2:length(pkg.globals$dirs)){
        names_tmp.list <- c(names_tmp.list,paste0("dummy",j-1));
        names_tmp.list <- c(names_tmp.list,paste(dirs[j],c("s","m","l","all"),sep="_"))
      }
      #print(names_tmp.list)
      names(tmp.list) <- names_tmp.list
      #print(tmp.list)
      for(mut in dirs){
        mut.idx <- species == mut;
        #for(sz in 1:3){
        #tmp.list <- vector("list",3)
        #names(tmp.list) <- c("s","m","l")
        split.tmp <- split(pc.mat[mut.idx,fm[k,"order_column"]],as.factor(size[mut.idx]))
        #print(paste(mut,names(split.tmp),sep="_"))
        tmp.list[paste(mut,names(split.tmp),sep="_")] <- split.tmp
        tmp.list[[paste(mut,"all",sep="_")]] <- unlist(split.tmp)
        #boxplot(tmp.list,col=cols[mut],ylim=ylim,ylab=rownames(fm)[k],names = c("small","medium","large","all"),main=paste("\n",xlab[mut],sep=""),srt=45)

        #}
      }
      rl <- floor(min(unlist(tmp.list),na.rm=TRUE))
      #rl <- rl - 0.2*rl
      rr <- ceiling(max(unlist(tmp.list),na.rm=TRUE))
      #rr <- rr + 0.1*rr
      pp <- pretty(c(rl,rr),n=4)
      b <- boxplot(tmp.list,col=c(rep(cols[1],4),0,rep(cols[2],4),0,rep(cols[3],4)),ylim=ylim,ylab=rownames(fm)[k],names = NA,main="",cex.axis=1.2,cex.lab=1.1,axes=FALSE)
      box()
      axis(2,at=pp)
      axis(1,at=c(1:4,6:9,11:14),rep("",12))
      # mtext(leg.list[[mut]],at=1:4,side=1,line=2,cex=0.8)
      mtext(leg,at=c(1:4,6:9,11:14),side=1,line=1.5,cex=0.8)
      mtext(xlab,side=3,at=c(2.5,7.5,12.5),col=cols)
    }
    dev.off()
  }
}
