# defaults based in microns
sizeThs.globals <- new.env()
# ts: the upper limit for small size cells
sizeThs.globals$small <- 1400
# tm: the upper limit for medium size cells
sizeThs.globals$medium <- 4042
# tl: the upper limit for large size cells, not in use so far
# could be used the filter out "aggregated (not properly separated) cells"
sizeThs.globals$large <- Inf

#' @title Set the default cell size thresholds.
#'
#' @description Set the size thresholds according to experimentally determined thresholds (in microns) for size categorization as reported in \code{Möller B, Poeschl Y, Plötner R, Bürstenbinder K (2017). PaCeQuant: A tool for high-throughput quantification of pavement cell shape characteristics. Plant Physiol 175: 998-1017}. These values correspond to the default values in \code{\link{setSizeThresholds}}.
#'
#'
#' @export
setDefaultSizeThresholds <- function(){
  sizeThs.globals$small <- 1400
  sizeThs.globals$medium <- 4042
}

#' @title Set user-selected cell size thresholds.
#'
#' @description This function can be used to set user-selected cell size thresholds for small (<ts), medium (≥ts <tm) and large cells (≥tm) in the same unit as selected in the PaCeQuant processing.
#'
#' @param ts the upper limit for small size cells. Default is \code{ts=1400} in microns.
#' @param tm the upper limit for medium size cells. Default is \code{tm=4042} in microns.
#'
#' @export
setSizeThresholds <- function(ts=1400, tm=4042){
  # todo: check range und check ts < tm
  #if(sum(th <= 0) > 0){
  #  stop("Please check the size threshold!")
  #}
  sizeThs.globals$small <- ts
  sizeThs.globals$medium <- tm
}

#' @title Determine size thresholds from data.
#'
#' @description This function determines the size thresholds from the subjected data (cell areas). The determined thresholds are automatically set (\code{\link{setSizeThresholds}}).
#'
#' @param data feature data containing list generated by \code{\link{readFeatureData}}.
#' @param quantile upper limit for size thresholds in unit of fraction.
#'
#' @export
determineCustomSizeThresholds <- function(data, quantile=0.9){
  stop("Not implemented. Will come soon...")
}

#' @title Return currently used cell size thresholds.
#'
#' @description Return the cell size thresholds peviously set with \code{\link{setDefaultSizeThresholds}} or \code{\link{setSizeThresholds}}.
#'
#' @return currently used cell size thresholds as a list with slot names:
#' \describe{
#'     \item{small}{the upper limit for small size cells}
#'     \item{medium}{the upper limit for medium size cells}
#'     \item{large}{the upper limit for large size cells}
#' }
#' @export
#'
getSizeThresholds <- function(){
  return(list(small=sizeThs.globals$small,medium=sizeThs.globals$medium,large=sizeThs.globals$large))
}
